==========
User Guide
==========

.. toctree::
    :hidden:

    why.rst
    installation.rst
    usage.rst
    examples.rst
    contrib/index.rst
    api/index.rst
    faq.rst
    changelog.md


This guide describes:

- :doc:`What is Espresso and why <why>`,
- :doc:`How to install Espresso <installation>`,
- :doc:`How to use Espresso <usage>` and :doc:`examples <examples>`,
- :doc:`Reference <contrib/index>` for individal test problems,
- :doc:`API reference <api/index>`, :doc:`FAQ <faq>`, and :doc:`Release notes <changelog>`

You may also wish to look at:

- The :doc:`../contributor_guide/index`, which explains how you can add a new test problem into Espresso, or improve an existing one;
- The :doc:`../developer_guide/index`, which describes the infrastructure that runs 'in the background' to build Espresso;
- Our `Github repository <https://github.com/inlab-geo/espresso/>`_ 
- The ``#espresso`` channel on `Slack`_

